#[non_exhaustive]pub enum AccumulatorValue {
Integer(u64),
IntegerTuple(u64, u64),
EventDigest(Vec<(u64, Digest)>),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Integer(u64)
IntegerTuple(u64, u64)
EventDigest(Vec<(u64, Digest)>)
A non-empty list of (event_index_in_transaction, event_digest) pairs.
This variant is used for authenticated event streams, where an accumulator records which events (by index within their transaction) have occurred, allowing cryptographic verification of the event log.