#[non_exhaustive]pub enum TransactionExpiration {
None,
Epoch(EpochId),
ValidDuring {
min_epoch: Option<EpochId>,
max_epoch: Option<EpochId>,
min_timestamp: Option<u64>,
max_timestamp: Option<u64>,
chain: Digest,
nonce: u32,
},
Validity {
min_epoch: Option<EpochId>,
max_epoch: Option<EpochId>,
min_timestamp: Option<u64>,
max_timestamp: Option<u64>,
chain: Digest,
nonce: u32,
allowed_proposers: Option<AllowedProposers>,
},
}Expand description
A TTL for a transaction
BCS
The BCS serialized form for this type is defined by the following ABNF:
transaction-expiration = %x00 ; none
=/ %x01 u64 ; epochVariants (Non-exhaustive)
This enum is marked as non-exhaustive
None
The transaction has no expiration
Epoch(EpochId)
Validators wont sign a transaction unless the expiration Epoch is greater than or equal to the current epoch
ValidDuring
ValidDuring enables gas payments from address balances.
When transactions use address balances for gas payment instead of explicit gas coins, we lose the natural transaction uniqueness and replay prevention that comes from mutation of gas coin objects.
By bounding expiration and providing a nonce, validators must only retain executed digests for the maximum possible expiry range to differentiate retries from unique transactions with otherwise identical inputs.
Fields
Validity
Everything in ValidDuring, plus a restriction on which validators may propose the
transaction in consensus.
Fields
allowed_proposers: Option<AllowedProposers>The validators allowed to propose this transaction in consensus, if it restricts them