pub struct ObjectReference { /* private fields */ }Expand description
Reference to an object
Contains sufficient information to uniquely identify a specific object.
BCS
The BCS serialized form for this type is defined by the following ABNF:
object-ref = address u64 digestImplementations
Sourceimpl ObjectReference
impl ObjectReference
Sourcepub fn new(object_id: Address, version: Version, digest: Digest) -> Self
pub fn new(object_id: Address, version: Version, digest: Digest) -> Self
Creates a new object reference from the object’s id, version, and digest.
Sourcepub fn object_id(&self) -> &Address
pub fn object_id(&self) -> &Address
Returns a reference to the object id that this ObjectReference is referring to.
Sourcepub fn version(&self) -> Version
pub fn version(&self) -> Version
Returns the version of the object that this ObjectReference is referring to.
Sourcepub fn digest(&self) -> &Digest
pub fn digest(&self) -> &Digest
Returns the digest of the object that this ObjectReference is referring to.
Sourcepub fn coin_reservation(
coin_type: &StructTag,
balance: u64,
epoch: u64,
chain_id: Digest,
owner: Address,
) -> Self
Available on crate features hash and serde only.
pub fn coin_reservation( coin_type: &StructTag, balance: u64, epoch: u64, chain_id: Digest, owner: Address, ) -> Self
hash and serde only.Construct a synthetic coin reservation reference.
The reservation ref encodes an address-balance reservation for coin
usage so that the server can reserve the specified balance of the
sender’s address balance and transparently create a Coin<T> without
requiring actual coin objects.
See the coin reservation protocol for the full specification.
Sourcepub fn into_parts(self) -> (Address, Version, Digest)
pub fn into_parts(self) -> (Address, Version, Digest)
Returns a 3-tuple containing the object id, version, and digest.